API documentation
*****************

Core
====

.. automodule:: girder_worker
   :members:

.. automodule:: girder_worker.task
   :members:

Transforms
----------

.. automodule:: girder_worker_utils.transforms.girder_io
   :members:

Docker
======

Tasks
-----

.. automodule:: girder_worker.docker.tasks
   :members: docker_run

Transforms
----------

.. automodule:: girder_worker.docker.transforms
   :members:

.. automodule:: girder_worker.docker.transforms.girder
   :members:
